@@ -22,10 +22,7 @@ def download_sha1_unzip(url, checksum, save_to_directory, unzip=True):
     except ImportError:
         use_requests = False
 
-    try:
-        import urllib.request as urllib
-    except ImportError:
-        import urllib2 as urllib
+    import urllib.request as urllib
     import hashlib
     import zipfile
 
@@ -39,7 +36,7 @@ def download_sha1_unzip(url, checksum, save_to_directory, unzip=True):
             data = the_file.read()
             cont_checksum = hashlib.sha1(data).hexdigest()
             if cont_checksum == checksum:
-                print("Skipping download url:%s: save_to:%s:" % (url, save_to))
+                print(f"Skipping download url:{url}: save_to:{save_to}:")
     else:
         print("Downloading...", url, checksum)
 
@@ -56,7 +53,7 @@ def download_sha1_unzip(url, checksum, save_to_directory, unzip=True):
 
         if checksum != cont_checksum:
             raise ValueError(
-                'url:%s should have checksum:%s: Has:%s: ' % (url, checksum, cont_checksum)
+                f'url:{url} should have checksum:{checksum}: Has:{cont_checksum}: '
             )
         with open(save_to, 'wb') as f:
             if use_requests:
@@ -65,63 +62,57 @@ def download_sha1_unzip(url, checksum, save_to_directory, unzip=True):
                 f.write(response)
 
     if unzip and filename.endswith('.zip'):
-        print("Unzipping :%s:" % save_to)
+        print(f"Unzipping :{save_to}:")
         with zipfile.ZipFile(save_to, 'r') as zip_ref:
             zip_dir = os.path.join(
                 save_to_directory,
                 filename.replace('.zip', '')
             )
             if os.path.exists(zip_dir):
-                print("Skipping unzip to zip_dir exists:%s:" % zip_dir)
+                print(f"Skipping unzip to zip_dir exists:{zip_dir}:")
             else:
                 os.mkdir(zip_dir)
                 zip_ref.extractall(zip_dir)
 
-def get_urls(x86=True, x64=True, sdl2=True):
+def get_urls(x86=True, x64=True):
     url_sha1 = []
-    if sdl2:
-        url_sha1.extend([
-            [
-            'https://www.libsdl.org/release/SDL2-devel-2.0.16-VC.zip',
-            '13d952c333f3c2ebe9b7bc0075b4ad2f784e7584',
-            ],
-            [
-            'https://www.libsdl.org/projects/SDL_image/release/SDL2_image-devel-2.0.5-VC.zip',
-            '137f86474691f4e12e76e07d58d5920c8d844d5b',
-            ],
-            [
-            'https://www.libsdl.org/projects/SDL_ttf/release/SDL2_ttf-devel-2.0.15-VC.zip',
-            '1436df41ebc47ac36e02ec9bda5699e80ff9bd27',
-            ],
-            [
-            'https://www.libsdl.org/projects/SDL_mixer/release/SDL2_mixer-devel-2.0.4-VC.zip',
-            '9097148f4529cf19f805ccd007618dec280f0ecc',
-            ],
-            [
-            # 'https://www.ijg.org/files/jpegsr9d.zip',
-            'https://www.pygame.org/ftp/jpegsr9d.zip',
-            'ed10aa2b5a0fcfe74f8a6f7611aeb346b06a1f99',
-            ],
-        ])
+    url_sha1.extend([
+        [
+        'https://www.libsdl.org/release/SDL2-devel-2.0.22-VC.zip',
+        'efa040633c4faf8b006c0c1e552456ca4e5a3a53',
+        ],
+        [
+        'https://www.libsdl.org/projects/SDL_image/release/SDL2_image-devel-2.0.5-VC.zip',
+        '137f86474691f4e12e76e07d58d5920c8d844d5b',
+        ],
+        [
+        'https://github.com/libsdl-org/SDL_ttf/releases/download/release-2.20.1/SDL2_ttf-devel-2.20.1-VC.zip',
+        '371606aceba450384428fd2852f73d2f6290b136'
+        ],
+        [
+        'https://github.com/libsdl-org/SDL_mixer/releases/download/release-2.6.2/SDL2_mixer-devel-2.6.2-VC.zip',
+        '000e3ea8a50261d46dbd200fb450b93c59ed4482',
+        ],
+    ])
     if x86:
         url_sha1.append([
-         'https://pygame.org/ftp/prebuilt-x86-pygame-1.9.2-20150922.zip',
-         'dbce1d5ea27b3da17273e047826d172e1c34b478'
+         'https://github.com/pygame/pygame/releases/download/2.1.3.dev4/prebuilt-x86-pygame-2.1.4-20220319.zip',
+         'bff2e50d65ec35274d33203e9fcaf5d53b31a696'
         ])
     if x64:
         url_sha1.append([
-         'https://pygame.org/ftp/prebuilt-x64-pygame-1.9.2-20150922.zip',
-         '3a5af3427b3aa13a0aaf5c4cb08daaed341613ed'
+         'https://github.com/pygame/pygame/releases/download/2.1.3.dev4/prebuilt-x64-pygame-2.1.4-20220319.zip',
+         '16b46596744ce9ef80e7e40fa72ddbafef1cf586'
         ])
     return url_sha1
 
-def download_prebuilts(temp_dir, x86=True, x64=True, sdl2=True):
+def download_prebuilts(temp_dir, x86=True, x64=True):
     """ For downloading prebuilt dependencies.
     """
     if not os.path.exists(temp_dir):
-        print("Making dir :%s:" % temp_dir)
+        print(f"Making dir :{temp_dir}:")
         os.makedirs(temp_dir)
-    for url, checksum in get_urls(x86=x86, x64=x64, sdl2=sdl2):
+    for url, checksum in get_urls(x86=x86, x64=x64):
         download_sha1_unzip(url, checksum, temp_dir, 1)
 
 def create_ignore_target_fnc(x64=False, x86=False):
@@ -170,19 +161,19 @@ def copytree(src, dst, symlinks=False, ignore=None):
         else:
             shutil.copy2(s, d)
 
-def place_downloaded_prebuilts(temp_dir, move_to_dir, x86=True, x64=True, sdl2=True):
+def place_downloaded_prebuilts(temp_dir, move_to_dir, x86=True, x64=True):
     """ puts the downloaded prebuilt files into the right place.
 
     Leaves the files in temp_dir. copies to move_to_dir
     """
     prebuilt_x64 = os.path.join(
         temp_dir,
-        'prebuilt-x64-pygame-1.9.2-20150922',
+        'prebuilt-x64-pygame-2.1.4-20220319',
         'prebuilt-x64'
     )
     prebuilt_x86 = os.path.join(
         temp_dir,
-        'prebuilt-x86-pygame-1.9.2-20150922',
+        'prebuilt-x86-pygame-2.1.4-20220319',
         'prebuilt-x86'
     )
 
@@ -202,29 +193,10 @@ def place_downloaded_prebuilts(temp_dir, move_to_dir, x86=True, x64=True, sdl2=T
     if x64:
         prebuilt_dirs.append('prebuilt-x64')
 
-    if not sdl2:
-        return
 
     for prebuilt_dir in prebuilt_dirs:
         path = os.path.join(move_to_dir, prebuilt_dir)
-        print("copying into %s" % path)
-
-        # update jpeg
-        for file in ('jerror.h', 'jmorecfg.h', 'jpeglib.h'):
-            shutil.copyfile(
-                os.path.join(
-                    temp_dir,
-                    'jpegsr9d',
-                    'jpeg-9d',
-                    file
-                ),
-                os.path.join(
-                    move_to_dir,
-                    prebuilt_dir,
-                    'include',
-                    file
-                )
-            )
+        print(f"copying into {path}")
 
         copy(
             os.path.join(
@@ -240,63 +212,63 @@ def place_downloaded_prebuilts(temp_dir, move_to_dir, x86=True, x64=True, sdl2=T
         copy(
             os.path.join(
                 temp_dir,
-                'SDL2_mixer-devel-2.0.4-VC/SDL2_mixer-2.0.4'
+                'SDL2_mixer-devel-2.6.2-VC/SDL2_mixer-2.6.2'
             ),
             os.path.join(
                 move_to_dir,
                 prebuilt_dir,
-                'SDL2_mixer-2.0.4'
+                'SDL2_mixer-2.6.2'
             )
         )
         copy(
             os.path.join(
                 temp_dir,
-                'SDL2_ttf-devel-2.0.15-VC/SDL2_ttf-2.0.15'
+                'SDL2_ttf-devel-2.20.1-VC/SDL2_ttf-2.20.1'
             ),
             os.path.join(
                 move_to_dir,
                 prebuilt_dir,
-                'SDL2_ttf-2.0.15'
+                'SDL2_ttf-2.20.1'
             )
         )
         copy(
             os.path.join(
                 temp_dir,
-                'SDL2-devel-2.0.16-VC/SDL2-2.0.16'
+                'SDL2-devel-2.0.22-VC/SDL2-2.0.22'
             ),
             os.path.join(
                 move_to_dir,
                 prebuilt_dir,
-                'SDL2-2.0.16'
+                'SDL2-2.0.22'
             )
         )
 
-def update(x86=True, x64=True, sdl2=True):
+def update(x86=True, x64=True):
     move_to_dir = "."
-    download_prebuilts(download_dir, x86=x86, x64=x64, sdl2=sdl2)
-    place_downloaded_prebuilts(download_dir, move_to_dir, x86=x86, x64=x64, sdl2=sdl2)
+    download_prebuilts(download_dir, x86=x86, x64=x64)
+    place_downloaded_prebuilts(download_dir, move_to_dir, x86=x86, x64=x64)
 
-def ask(x86=True, x64=True, sdl2=True):
+def ask(x86=True, x64=True):
     move_to_dir = "."
     if x64:
-        dest_str = "\"%s/prebuilt-x64\"" % move_to_dir
+        dest_str = f"\"{move_to_dir}/prebuilt-x64\""
     else:
         dest_str = ""
     if x86:
         if dest_str:
-            dest_str = "%s and " % dest_str
-        dest_str = "%s\"%s/prebuilt-x86\"" % (dest_str, move_to_dir)
+            dest_str = f"{dest_str} and "
+        dest_str = f"{dest_str}\"{move_to_dir}/prebuilt-x86\""
     logging.info('Downloading prebuilts to "%s" and copying to %s.', (download_dir, dest_str))
     download_prebuilt = True
 
     if download_prebuilt:
-        update(x86=x86, x64=x64, sdl2=sdl2)
+        update(x86=x86, x64=x64)
     return download_prebuilt
 
-def cached(x86=True, x64=True, sdl2=True):
+def cached(x86=True, x64=True):
     if not os.path.isdir(download_dir):
         return False
-    for url, check in get_urls(x86=x86, x64=x64, sdl2=sdl2):
+    for url, check in get_urls(x86=x86, x64=x64):
         filename = os.path.split(url)[-1]
         save_to = os.path.join(download_dir, filename)
         if not os.path.exists(save_to):
