@@ -10,6 +10,7 @@ rst_build_dir = os.path.join('docs', 'generated')
 rst_doctree_dir = os.path.join(rst_build_dir, 'doctrees')
 c_header_dir = os.path.join('src_c', 'doc')
 
+
 def run():
     full_generation_flag = False
     for argument in sys.argv[1:]:
@@ -17,17 +18,17 @@ def run():
             full_generation_flag = True
     try:
         subprocess_args = [sys.executable, '-m', 'sphinx',
-                            '-b', 'html',
-                            '-d', rst_doctree_dir,
-                            '-D', 'headers_dest=%s' % (c_header_dir,),
-                            '-D', 'headers_mkdirs=0',
-                            rst_source_dir,
-                            rst_build_dir,]
+                           '-b', 'html',
+                           '-d', rst_doctree_dir,
+                           '-D', f'headers_dest={c_header_dir}',
+                           '-D', 'headers_mkdirs=0',
+                           rst_source_dir,
+                           rst_build_dir, ]
         if full_generation_flag:
             subprocess_args.append('-E')
-        print("executing sphinx in subprocess with args:", subprocess_args)
+        print("Executing sphinx in subprocess with args:", subprocess_args)
         return subprocess.run(subprocess_args).returncode
-    except:
+    except Exception:
         print('---')
         print('Have you installed sphinx?')
         print('---')
