@@ -20,7 +20,7 @@
 
 /*
   This module exports a proxy object that exposes another object's
-  data throught the Python buffer protocol or the array interface.
+  data through the Python buffer protocol or the array interface.
   The new buffer protocol is available for Python 3.x. For Python 2.x
   only the old protocol is implemented (for PyPy compatibility).
   Both the C level array structure - __array_struct__ - interface and
@@ -58,13 +58,9 @@
 typedef struct pgBufproxyObject_s {
     PyObject_HEAD PyObject *obj; /* Wrapped object (parent)     */
     pg_buffer *pg_view_p;        /* For array interface export  */
-#if PG_ENABLE_OLDBUF
-    Py_ssize_t segcount; /* bf_getsegcount return value */
-    Py_ssize_t seglen;   /* bf_getsegcount len argument */
-#endif
-    getbufferproc get_buffer; /* pg_buffer get callback      */
-    PyObject *dict;           /* Allow arbitrary attributes  */
-    PyObject *weakrefs;       /* Reference cycles can happen */
+    getbufferproc get_buffer;    /* pg_buffer get callback      */
+    PyObject *dict;              /* Allow arbitrary attributes  */
+    PyObject *weakrefs;          /* Reference cycles can happen */
 } pgBufproxyObject;
 
 static int
@@ -249,7 +245,7 @@ _proxy_zombie_get_buffer(PyObject *obj, Py_buffer *view_p, int flags)
 static PyObject *
 proxy_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
-    PyObject *obj = 0;
+    PyObject *obj;
     getbufferproc get_buffer = (getbufferproc)pgObject_GetBuffer;
 
     if (!PyArg_ParseTuple(args, "O:Bufproxy", &obj)) {
@@ -375,7 +371,7 @@ proxy_get_raw(pgBufproxyObject *self, PyObject *closure)
         PyErr_SetString(PyExc_ValueError, "the bytes are not contiguous");
         return 0;
     }
-    py_raw = Bytes_FromStringAndSize((char *)view_p->buf, view_p->len);
+    py_raw = PyBytes_FromStringAndSize((char *)view_p->buf, view_p->len);
     if (!py_raw) {
         _proxy_release_view(self);
         return 0;
@@ -390,7 +386,7 @@ proxy_get_length(pgBufproxyObject *self, PyObject *closure)
     PyObject *py_length = 0;
 
     if (view_p) {
-        py_length = PyInt_FromSsize_t(view_p->len);
+        py_length = PyLong_FromSsize_t(view_p->len);
         if (!py_length) {
             _proxy_release_view(self);
         }
@@ -411,7 +407,7 @@ proxy_repr(pgBufproxyObject *self)
     if (!view_p) {
         return 0;
     }
-    return Text_FromFormat("<BufferProxy(%zd)>", view_p->len);
+    return PyUnicode_FromFormat("<BufferProxy(%zd)>", view_p->len);
 }
 
 /**
@@ -426,12 +422,10 @@ proxy_write(pgBufproxyObject *self, PyObject *args, PyObject *kwds)
     Py_ssize_t offset = 0;
     char *keywords[] = {"buffer", "offset", 0};
 
-#define ARG_FORMAT "s#|n"
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, ARG_FORMAT, keywords, &buf,
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "s#|n", keywords, &buf,
                                      &buflen, &offset)) {
         return 0;
     }
-#undef ARG_FORMAT
 
     if (proxy_getbuffer(self, &view, PyBUF_PG_VIEW)) {
         return 0;
@@ -522,274 +516,35 @@ proxy_releasebuffer(pgBufproxyObject *self, Py_buffer *view_p)
     PyMem_Free(view_p->internal);
 }
 
-#if PG_ENABLE_OLDBUF
-static int
-_is_byte_view(Py_buffer *view_p)
-{
-    const char *format = view_p->format;
-
-    /* Conditional ||'s */
-    return ((!format) || (format[0] == 'B' && format[1] == '\0') ||
-            (format[0] == '=' && format[1] == 'B' && format[2] == '\0') ||
-            (format[0] == '<' && format[1] == 'B' && format[2] == '\0') ||
-            (format[0] == '>' && format[1] == 'B' && format[2] == '\0') ||
-            (format[0] == '@' && format[1] == 'B' && format[2] == '\0') ||
-            (format[0] == '!' && format[1] == 'B' && format[2] == '\0'));
-}
-
-static Py_ssize_t
-proxy_getreadbuf(pgBufproxyObject *self, Py_ssize_t _index, void **ptr)
-{
-    Py_buffer *view_p = (Py_buffer *)self->pg_view_p;
-    Py_ssize_t offset = 0;
-    Py_ssize_t dim;
-
-    if (_index < 0 || _index >= self->segcount) {
-        if (_index == 0 && self->segcount == 0) {
-            *ptr = 0;
-            return 0;
-        }
-        PyErr_SetString(PyExc_IndexError, "segment index out of range");
-        return -1;
-    }
-    if (!view_p) {
-        *ptr = 0;
-        return 0;
-    }
-    if (self->segcount == 1) {
-        assert(_index == 0);
-        *ptr = view_p->buf;
-        return view_p->len;
-    }
-    /* Segments will be strictly in C contiguous order, which may
-       differ from the actual order in memory. It can affect buffer
-       copying. This may never be an issue, though, since Python
-       never directly supported multi-segment buffers. And besides,
-       the old buffer is deprecated. */
-    for (dim = view_p->ndim - 1; dim != -1; --dim) {
-        offset += _index % view_p->shape[dim] * view_p->strides[dim];
-        _index /= view_p->shape[dim];
-    }
-    *ptr = (char *)view_p->buf + offset;
-    return view_p->itemsize;
-}
-
-static Py_ssize_t
-proxy_getwritebuf(pgBufproxyObject *self, Py_ssize_t _index, void **ptr)
-{
-    void *p;
-    Py_ssize_t seglen = proxy_getreadbuf(self, _index, &p);
-
-    if (seglen < 0) {
-        return -1;
-    }
-    if (seglen > 0 && /* cond. && */
-        ((Py_buffer *)self->pg_view_p)->readonly) {
-        PyErr_SetString(PyExc_ValueError, "buffer is not writeable");
-        return -1;
-    }
-    *ptr = p;
-    return seglen;
-}
-
-static Py_ssize_t
-proxy_getsegcount(pgBufproxyObject *self, Py_ssize_t *lenp)
-{
-    Py_buffer *view_p = _proxy_get_view(self);
-
-    if (!view_p) {
-        PyErr_Clear();
-        self->seglen = 0;
-        self->segcount = 0;
-    }
-    else if (view_p->ndim == 0 ||
-             (view_p->ndim == 1 && _is_byte_view(view_p))) {
-        self->seglen = view_p->len;
-        self->segcount = 1;
-    }
-    else {
-        self->seglen = view_p->len;
-        self->segcount = view_p->len / view_p->itemsize;
-    }
-    if (lenp) {
-        *lenp = self->seglen;
-    }
-    return self->segcount;
-}
-
-#endif
-
 #define PROXY_BUFFERPROCS (&proxy_bufferprocs)
 
 static PyBufferProcs proxy_bufferprocs = {
-#if PG_ENABLE_OLDBUF
-    (readbufferproc)proxy_getreadbuf,
-    (writebufferproc)proxy_getwritebuf,
-    (segcountproc)proxy_getsegcount,
-    0
-#elif HAVE_OLD_BUFPROTO
-    0, 0, 0,
-    0
-#endif
+    (getbufferproc)proxy_getbuffer, (releasebufferproc)proxy_releasebuffer};
 
-#if HAVE_OLD_BUFPROTO
-    ,
-#endif
-    (getbufferproc)proxy_getbuffer,
-    (releasebufferproc)proxy_releasebuffer
-};
-
-
-#if !defined(PROXY_BUFFERPROCS)
-#define PROXY_BUFFERPROCS 0
-#endif
-
-#if PY2
-#define PROXY_TPFLAGS                                                \
-    (Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | \
-     Py_TPFLAGS_HAVE_NEWBUFFER)
-#else
 #define PROXY_TPFLAGS \
     (Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC)
-#endif
 
 static PyTypeObject pgBufproxy_Type = {
-    TYPE_HEAD(NULL, 0) PROXY_TYPE_FULLNAME, /* tp_name */
-    sizeof(pgBufproxyObject),               /* tp_basicsize */
-    0,                                      /* tp_itemsize */
-    (destructor)proxy_dealloc,              /* tp_dealloc */
-    0,                                      /* tp_print */
-    0,                                      /* tp_getattr */
-    0,                                      /* tp_setattr */
-    0,                                      /* tp_compare */
-    (reprfunc)proxy_repr,                   /* tp_repr */
-    0,                                      /* tp_as_number */
-    0,                                      /* tp_as_sequence */
-    0,                                      /* tp_as_mapping */
-    0,                                      /* tp_hash */
-    0,                                      /* tp_call */
-    0,                                      /* tp_str */
-    0,                                      /* tp_getattro */
-    0,                                      /* tp_setattro */
-    PROXY_BUFFERPROCS,                      /* tp_as_buffer */
-    PROXY_TPFLAGS,                          /* tp_flags */
-    DOC_PYGAMEBUFFERPROXY,
-    (traverseproc)proxy_traverse,         /* tp_traverse */
-    0,                                    /* tp_clear */
-    0,                                    /* tp_richcompare */
-    offsetof(pgBufproxyObject, weakrefs), /* tp_weaklistoffset */
-    0,                                    /* tp_iter */
-    0,                                    /* tp_iternext */
-    proxy_methods,                        /* tp_methods */
-    0,                                    /* tp_members */
-    proxy_getsets,                        /* tp_getset */
-    0,                                    /* tp_base */
-    0,                                    /* tp_dict */
-    0,                                    /* tp_descr_get */
-    0,                                    /* tp_descr_set */
-    offsetof(pgBufproxyObject, dict),     /* tp_dictoffset */
-    0,                                    /* tp_init */
-    PyType_GenericAlloc,                  /* tp_alloc */
-    proxy_new,                            /* tp_new */
-    PyObject_GC_Del,                      /* tp_free */
+    PyVarObject_HEAD_INIT(NULL, 0).tp_name = PROXY_TYPE_FULLNAME,
+    .tp_basicsize = sizeof(pgBufproxyObject),
+    .tp_dealloc = (destructor)proxy_dealloc,
+    .tp_repr = (reprfunc)proxy_repr,
+    .tp_as_buffer = PROXY_BUFFERPROCS,
+    .tp_flags = PROXY_TPFLAGS,
+    .tp_doc = DOC_PYGAMEBUFFERPROXY,
+    .tp_traverse = (traverseproc)proxy_traverse,
+    .tp_weaklistoffset = offsetof(pgBufproxyObject, weakrefs),
+    .tp_methods = proxy_methods,
+    .tp_getset = proxy_getsets,
+    .tp_dictoffset = offsetof(pgBufproxyObject, dict),
+    .tp_alloc = PyType_GenericAlloc,
+    .tp_new = proxy_new,
+    .tp_free = PyObject_GC_Del,
 };
 
 /**** Module methods ***/
 
-#if PG_ENABLE_OLDBUF
-static PyObject *
-get_read_buffer(PyObject *self, PyObject *args, PyObject *kwds)
-{
-    long segment = 0;
-    PyObject *obj = 0;
-    Py_ssize_t len = 0;
-    void *ptr = 0;
-    readbufferproc getreadbuffer = 0;
-    static char *keywords[] = {"obj", "segment", 0};
-
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "Ol", keywords, &obj,
-                                     &segment)) {
-        return 0;
-    }
-    if (!Py_TYPE(obj)->tp_as_buffer) {
-        PyErr_SetString(PyExc_ValueError, "No tp_as_buffer struct");
-        return 0;
-    }
-    getreadbuffer = Py_TYPE(obj)->tp_as_buffer->bf_getreadbuffer;
-    if (!getreadbuffer) {
-        PyErr_SetString(PyExc_ValueError, "No bf_getreadbuffer slot function");
-        return 0;
-    }
-    len = getreadbuffer(obj, segment, &ptr);
-    if (len < 0) {
-        return 0;
-    }
-    return Py_BuildValue("nN", len, PyLong_FromVoidPtr(ptr));
-}
-
-static PyObject *
-get_write_buffer(PyObject *self, PyObject *args, PyObject *kwds)
-{
-    long segment = 0;
-    PyObject *obj = 0;
-    Py_ssize_t len = 0;
-    void *ptr = 0;
-    writebufferproc getwritebuffer = 0;
-    static char *keywords[] = {"obj", "segment", 0};
-
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "Ol", keywords, &obj,
-                                     &segment)) {
-        return 0;
-    }
-    if (!Py_TYPE(obj)->tp_as_buffer) {
-        PyErr_SetString(PyExc_ValueError, "No tp_as_buffer struct");
-        return 0;
-    }
-    getwritebuffer = Py_TYPE(obj)->tp_as_buffer->bf_getwritebuffer;
-    if (!getwritebuffer) {
-        PyErr_SetString(PyExc_ValueError,
-                        "No bf_getwritebuffer slot function");
-        return 0;
-    }
-    len = getwritebuffer(obj, segment, &ptr);
-    if (len < 0) {
-        return 0;
-    }
-    return Py_BuildValue("nN", len, PyLong_FromVoidPtr(ptr));
-}
-
-static PyObject *
-get_segcount(PyObject *self, PyObject *obj)
-{
-    Py_ssize_t segcount = 0;
-    Py_ssize_t len = 0;
-    segcountproc getsegcount = 0;
-
-    if (!Py_TYPE(obj)->tp_as_buffer) {
-        PyErr_SetString(PyExc_ValueError, "No tp_as_buffer struct");
-        return 0;
-    }
-    getsegcount = Py_TYPE(obj)->tp_as_buffer->bf_getsegcount;
-    if (!getsegcount) {
-        PyErr_SetString(PyExc_ValueError, "No bf_getsegcount slot function");
-        return 0;
-    }
-    segcount = getsegcount(obj, &len);
-    return Py_BuildValue("ll", (long)segcount, (long)len);
-}
-
-#endif
-
-static PyMethodDef bufferproxy_methods[] = {
-#if PG_ENABLE_OLDBUF
-    {"get_read_buffer", (PyCFunction)get_read_buffer,
-     METH_VARARGS | METH_KEYWORDS, "call bf_getreadbuffer slot function"},
-    {"get_write_buffer", (PyCFunction)get_write_buffer,
-     METH_VARARGS | METH_KEYWORDS, "call bf_getwritebuffer slot function"},
-    {"get_segcount", (PyCFunction)get_segcount, METH_O,
-     "call bf_getsegcount slot function"},
-#endif
-    {0, 0, 0, 0}};
+static PyMethodDef bufferproxy_methods[] = {{0, 0, 0, 0}};
 
 /**** Public C api ***/
 
@@ -836,11 +591,9 @@ pgBufproxy_Trip(PyObject *obj)
 
 MODINIT_DEFINE(bufferproxy)
 {
-    PyObject *module;
-    PyObject *apiobj;
+    PyObject *module, *apiobj;
     static void *c_api[PYGAMEAPI_BUFPROXY_NUMSLOTS];
 
-#if PY3
     static struct PyModuleDef _module = {PyModuleDef_HEAD_INIT,
                                          PROXY_MODNAME,
                                          bufferproxy_doc,
@@ -850,35 +603,32 @@ MODINIT_DEFINE(bufferproxy)
                                          NULL,
                                          NULL,
                                          NULL};
-#endif
 
     /* imported needed apis */
     import_pygame_base();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     /* prepare exported types */
     if (PyType_Ready(&pgBufproxy_Type) < 0) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
 #define bufferproxy_docs ""
 
     /* create the module */
-#if PY3
     module = PyModule_Create(&_module);
-#else
-    module = Py_InitModule3(MODPREFIX PROXY_MODNAME, bufferproxy_methods,
-                            bufferproxy_doc);
-#endif
+    if (!module) {
+        return NULL;
+    }
 
     Py_INCREF(&pgBufproxy_Type);
     if (PyModule_AddObject(module, PROXY_TYPE_NAME,
                            (PyObject *)&pgBufproxy_Type)) {
         Py_DECREF(&pgBufproxy_Type);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
 #if PYGAMEAPI_BUFPROXY_NUMSLOTS != 4
 #error export slot count mismatch
@@ -888,14 +638,10 @@ MODINIT_DEFINE(bufferproxy)
     c_api[2] = pgBufproxy_GetParent;
     c_api[3] = pgBufproxy_Trip;
     apiobj = encapsulate_api(c_api, PROXY_MODNAME);
-    if (apiobj == NULL) {
-        DECREF_MOD(module);
-        MODINIT_ERROR;
-    }
     if (PyModule_AddObject(module, PYGAMEAPI_LOCAL_ENTRY, apiobj)) {
-        Py_DECREF(apiobj);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_XDECREF(apiobj);
+        Py_DECREF(module);
+        return NULL;
     }
-    MODINIT_RETURN(module);
+    return module;
 }
