@@ -61,11 +61,7 @@ _pg_push_music_event(int type)
     e = (pgEventObject *)pgEvent_New2(type, NULL);
     if (e) {
         pgEvent_FillUserEvent(e, &event);
-#if IS_SDLv1
-        if (SDL_PushEvent(&event) < 0)
-#else
         if (SDL_PushEvent(&event) <= 0)
-#endif
             Py_DECREF(e->dict);
         Py_DECREF(e);
     }
@@ -100,7 +96,7 @@ music_play(PyObject *self, PyObject *args, PyObject *keywds)
 {
     int loops = 0;
     float startpos = 0.0;
-    int val, volume = 0, fade_ms=0;
+    int val, volume = 0, fade_ms = 0;
 
     static char *kwids[] = {"loops", "start", "fade_ms", NULL};
     if (!PyArg_ParseTupleAndKeywords(args, keywds, "|ifi", kwids, &loops,
@@ -111,7 +107,7 @@ music_play(PyObject *self, PyObject *args, PyObject *keywds)
     if (!current_music)
         return RAISE(pgExc_SDLError, "music not loaded");
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     Mix_HookMusicFinished(endmusic_callback);
     Mix_SetPostMix(mixmusic_callback, NULL);
     Mix_QuerySpec(&music_frequency, &music_format, &music_channels);
@@ -121,22 +117,23 @@ music_play(PyObject *self, PyObject *args, PyObject *keywds)
     volume = Mix_VolumeMusic(-1);
     val = Mix_FadeInMusicPos(current_music, loops, fade_ms, startpos);
     Mix_VolumeMusic(volume);
-    Py_END_ALLOW_THREADS
-        if (val == -1) return RAISE(pgExc_SDLError, SDL_GetError());
+    Py_END_ALLOW_THREADS;
+    if (val == -1)
+        return RAISE(pgExc_SDLError, SDL_GetError());
 
     Py_RETURN_NONE;
 }
 
 static PyObject *
-music_get_busy(PyObject *self, PyObject *args)
+music_get_busy(PyObject *self, PyObject *_null)
 {
     int playing;
 
     MIXER_INIT_CHECK();
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     playing = (Mix_PlayingMusic() && !Mix_PausedMusic());
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
 
     return PyBool_FromLong(playing);
 }
@@ -150,7 +147,7 @@ music_fadeout(PyObject *self, PyObject *args)
 
     MIXER_INIT_CHECK();
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     /* To prevent the queue_music from playing, free it before fading. */
     if (queue_music) {
         Mix_FreeMusic(queue_music);
@@ -160,16 +157,16 @@ music_fadeout(PyObject *self, PyObject *args)
 
     Mix_FadeOutMusic(_time);
 
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
     Py_RETURN_NONE;
 }
 
 static PyObject *
-music_stop(PyObject *self, PyObject *args)
+music_stop(PyObject *self, PyObject *_null)
 {
     MIXER_INIT_CHECK();
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     /* To prevent the queue_music from playing, free it before stopping. */
     if (queue_music) {
         Mix_FreeMusic(queue_music);
@@ -179,12 +176,12 @@ music_stop(PyObject *self, PyObject *args)
 
     Mix_HaltMusic();
 
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
     Py_RETURN_NONE;
 }
 
 static PyObject *
-music_pause(PyObject *self, PyObject *args)
+music_pause(PyObject *self, PyObject *_null)
 {
     MIXER_INIT_CHECK();
 
@@ -193,22 +190,24 @@ music_pause(PyObject *self, PyObject *args)
 }
 
 static PyObject *
-music_unpause(PyObject *self, PyObject *args)
+music_unpause(PyObject *self, PyObject *_null)
 {
     MIXER_INIT_CHECK();
 
     Mix_ResumeMusic();
+    /* need to set pos_time for the adjusted time spent paused*/
+    music_pos_time = SDL_GetTicks();
     Py_RETURN_NONE;
 }
 
 static PyObject *
-music_rewind(PyObject *self, PyObject *args)
+music_rewind(PyObject *self, PyObject *_null)
 {
     MIXER_INIT_CHECK();
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     Mix_RewindMusic();
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
 
     Py_RETURN_NONE;
 }
@@ -223,15 +222,15 @@ music_set_volume(PyObject *self, PyObject *args)
 
     MIXER_INIT_CHECK();
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     Mix_VolumeMusic((int)(volume * 128));
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
 
     Py_RETURN_NONE;
 }
 
 static PyObject *
-music_get_volume(PyObject *self, PyObject *args)
+music_get_volume(PyObject *self, PyObject *_null)
 {
     int volume;
     MIXER_INIT_CHECK();
@@ -252,9 +251,9 @@ music_set_pos(PyObject *self, PyObject *arg)
 
     MIXER_INIT_CHECK();
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     position_set = Mix_SetMusicPosition(pos);
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
 
     if (position_set == -1)
         return RAISE(pgExc_SDLError, "set_pos unsupported for this codec");
@@ -263,7 +262,7 @@ music_set_pos(PyObject *self, PyObject *arg)
 }
 
 static PyObject *
-music_get_pos(PyObject *self, PyObject *args)
+music_get_pos(PyObject *self, PyObject *_null)
 {
     long ticks;
 
@@ -278,7 +277,7 @@ music_get_pos(PyObject *self, PyObject *args)
     if (!Mix_PausedMusic())
         ticks += SDL_GetTicks() - music_pos_time;
 
-    return PyInt_FromLong((long)ticks);
+    return PyLong_FromLong((long)ticks);
 }
 
 static PyObject *
@@ -293,16 +292,16 @@ music_set_endevent(PyObject *self, PyObject *args)
 }
 
 static PyObject *
-music_get_endevent(PyObject *self, PyObject *args)
+music_get_endevent(PyObject *self, PyObject *_null)
 {
-    return PyInt_FromLong(endmusic_event);
+    return PyLong_FromLong(endmusic_event);
 }
 
 Mix_MusicType
 _get_type_from_hint(char *namehint)
 {
     Mix_MusicType type = MUS_NONE;
-    const char *dot;
+    char *dot;
 
     // Adjusts namehint into a mere file extension component
     if (namehint != NULL) {
@@ -315,9 +314,10 @@ _get_type_from_hint(char *namehint)
         return type;
     }
 
-    /* Copied almost directly from SDL_mixer. Originally meant to check file extensions
-    * to get a hint of what music type it should be.
-    * https://github.com/libsdl-org/SDL_mixer/blob/master/src/music.c#L586-L631 */
+    /* Copied almost directly from SDL_mixer. Originally meant to check file
+     * extensions to get a hint of what music type it should be.
+     * https://github.com/libsdl-org/SDL_mixer/blob/master/src/music.c#L586-L631
+     */
     if (SDL_strcasecmp(namehint, "WAV") == 0) {
         type = MUS_WAV;
     }
@@ -369,40 +369,43 @@ _get_type_from_hint(char *namehint)
     return type;
 }
 
-Mix_Music * 
-_load_music(PyObject *obj, char *namehint) {
+Mix_Music *
+_load_music(PyObject *obj, char *namehint)
+{
     Mix_Music *new_music = NULL;
-    char* ext = NULL;
+    char *ext = NULL;
     SDL_RWops *rw = NULL;
-    PyObject* _type = NULL;
-    PyObject* error = NULL;
-    PyObject* _traceback = NULL;
+    PyObject *_type = NULL;
+    PyObject *error = NULL;
+    PyObject *_traceback = NULL;
 
     MIXER_INIT_CHECK();
 
     rw = pgRWops_FromObject(obj);
-    if (rw == NULL) { /* stop on NULL, error already set is what we SHOULD do */
+    if (rw ==
+        NULL) { /* stop on NULL, error already set is what we SHOULD do */
         PyErr_Fetch(&_type, &error, &_traceback);
         PyErr_SetObject(pgExc_SDLError, error);
         Py_XDECREF(_type);
         Py_XDECREF(_traceback);
         return NULL;
-    } 
+    }
     if (namehint) {
         ext = namehint;
-    } else {
+    }
+    else {
         ext = pgRWops_GetFileExtension(rw);
     }
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     new_music = Mix_LoadMUSType_RW(rw, _get_type_from_hint(ext), SDL_TRUE);
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
 
     if (!new_music) {
         PyErr_SetString(pgExc_SDLError, SDL_GetError());
         return NULL;
     }
-    
+
     return new_music;
 }
 
@@ -414,18 +417,18 @@ music_load(PyObject *self, PyObject *args, PyObject *keywds)
     char *namehint = NULL;
     static char *kwids[] = {"filename", "namehint", NULL};
 
-    if (!PyArg_ParseTupleAndKeywords(args, keywds, "O|s", kwids, &obj, &namehint))
+    if (!PyArg_ParseTupleAndKeywords(args, keywds, "O|s", kwids, &obj,
+                                     &namehint))
         return NULL;
 
     MIXER_INIT_CHECK();
 
     new_music = _load_music(obj, namehint);
-    if (new_music == NULL) // meaning it has an error to return
+    if (new_music == NULL)  // meaning it has an error to return
         return NULL;
 
-    Py_BEGIN_ALLOW_THREADS
-    if (current_music != NULL)
-    {
+    Py_BEGIN_ALLOW_THREADS;
+    if (current_music != NULL) {
         Mix_FreeMusic(current_music);
         current_music = NULL;
     }
@@ -434,18 +437,18 @@ music_load(PyObject *self, PyObject *args, PyObject *keywds)
         queue_music = NULL;
         queue_music_loops = 0;
     }
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
 
     current_music = new_music;
     Py_RETURN_NONE;
 }
 
 static PyObject *
-music_unload(PyObject *self, PyObject *noarg)
+music_unload(PyObject *self, PyObject *_null)
 {
     MIXER_INIT_CHECK();
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     if (current_music) {
         Mix_FreeMusic(current_music);
         current_music = NULL;
@@ -455,7 +458,7 @@ music_unload(PyObject *self, PyObject *noarg)
         queue_music = NULL;
         queue_music_loops = 0;
     }
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
 
     Py_RETURN_NONE;
 }
@@ -469,23 +472,24 @@ music_queue(PyObject *self, PyObject *args, PyObject *keywds)
     char *namehint = NULL;
     static char *kwids[] = {"filename", "namehint", "loops", NULL};
 
-    if (!PyArg_ParseTupleAndKeywords(args, keywds, "O|si", kwids, &obj, &namehint, &loops))
+    if (!PyArg_ParseTupleAndKeywords(args, keywds, "O|si", kwids, &obj,
+                                     &namehint, &loops))
         return NULL;
 
     MIXER_INIT_CHECK();
 
     queue_music_loops = loops;
-    
+
     local_queue_music = _load_music(obj, namehint);
-    if (local_queue_music == NULL) // meaning it has an error to return
+    if (local_queue_music == NULL)  // meaning it has an error to return
         return NULL;
 
-    Py_BEGIN_ALLOW_THREADS
+    Py_BEGIN_ALLOW_THREADS;
     /* Free any existing queued music. */
     if (queue_music != NULL) {
         Mix_FreeMusic(queue_music);
     }
-    Py_END_ALLOW_THREADS
+    Py_END_ALLOW_THREADS;
 
     queue_music = local_queue_music;
 
@@ -500,28 +504,24 @@ static PyMethodDef _music_methods[] = {
 
     {"play", (PyCFunction)music_play, METH_VARARGS | METH_KEYWORDS,
      DOC_PYGAMEMIXERMUSICPLAY},
-    {"get_busy", music_get_busy, METH_NOARGS,
-     DOC_PYGAMEMIXERMUSICGETBUSY},
+    {"get_busy", music_get_busy, METH_NOARGS, DOC_PYGAMEMIXERMUSICGETBUSY},
     {"fadeout", music_fadeout, METH_VARARGS, DOC_PYGAMEMIXERMUSICFADEOUT},
     {"stop", music_stop, METH_NOARGS, DOC_PYGAMEMIXERMUSICSTOP},
-    {"pause", music_pause, METH_NOARGS,
-     DOC_PYGAMEMIXERMUSICPAUSE},
-    {"unpause", music_unpause, METH_NOARGS,
-     DOC_PYGAMEMIXERMUSICUNPAUSE},
-    {"rewind", music_rewind, METH_NOARGS,
-     DOC_PYGAMEMIXERMUSICREWIND},
+    {"pause", music_pause, METH_NOARGS, DOC_PYGAMEMIXERMUSICPAUSE},
+    {"unpause", music_unpause, METH_NOARGS, DOC_PYGAMEMIXERMUSICUNPAUSE},
+    {"rewind", music_rewind, METH_NOARGS, DOC_PYGAMEMIXERMUSICREWIND},
     {"set_volume", music_set_volume, METH_VARARGS,
      DOC_PYGAMEMIXERMUSICSETVOLUME},
     {"get_volume", music_get_volume, METH_NOARGS,
      DOC_PYGAMEMIXERMUSICGETVOLUME},
-    {"set_pos", music_set_pos, METH_O,
-     DOC_PYGAMEMIXERMUSICSETPOS},
-    {"get_pos", music_get_pos, METH_NOARGS,
-     DOC_PYGAMEMIXERMUSICGETPOS},
+    {"set_pos", music_set_pos, METH_O, DOC_PYGAMEMIXERMUSICSETPOS},
+    {"get_pos", music_get_pos, METH_NOARGS, DOC_PYGAMEMIXERMUSICGETPOS},
 
-    {"load", (PyCFunction)music_load, METH_VARARGS | METH_KEYWORDS, DOC_PYGAMEMIXERMUSICLOAD},
+    {"load", (PyCFunction)music_load, METH_VARARGS | METH_KEYWORDS,
+     DOC_PYGAMEMIXERMUSICLOAD},
     {"unload", music_unload, METH_NOARGS, DOC_PYGAMEMIXERMUSICUNLOAD},
-    {"queue", (PyCFunction)music_queue, METH_VARARGS | METH_KEYWORDS, DOC_PYGAMEMIXERMUSICQUEUE},
+    {"queue", (PyCFunction)music_queue, METH_VARARGS | METH_KEYWORDS,
+     DOC_PYGAMEMIXERMUSICQUEUE},
 
     {NULL, NULL, 0, NULL}};
 
@@ -530,7 +530,6 @@ MODINIT_DEFINE(mixer_music)
     PyObject *module;
     PyObject *cobj;
 
-#if PY3
     static struct PyModuleDef _module = {PyModuleDef_HEAD_INIT,
                                          "mixer_music",
                                          DOC_PYGAMEMIXERMUSIC,
@@ -540,55 +539,41 @@ MODINIT_DEFINE(mixer_music)
                                          NULL,
                                          NULL,
                                          NULL};
-#endif
 
     /* imported needed apis; Do this first so if there is an error
        the module is not loaded.
     */
     import_pygame_base();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
     import_pygame_rwobject();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
     import_pygame_event();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
     /* create the module */
-#if PY3
     module = PyModule_Create(&_module);
-#else
-    module = Py_InitModule3(MODPREFIX "mixer_music", _music_methods,
-                            DOC_PYGAMEMIXERMUSIC);
-#endif
     if (module == NULL) {
-        MODINIT_ERROR;
+        return NULL;
     }
     cobj = PyCapsule_New(&current_music, "pygame.music_mixer._MUSIC_POINTER",
                          NULL);
-    if (cobj == NULL) {
-        DECREF_MOD(module);
-        MODINIT_ERROR;
-    }
-    if (PyModule_AddObject(module, "_MUSIC_POINTER", cobj) < 0) {
-        Py_DECREF(cobj);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+    if (PyModule_AddObject(module, "_MUSIC_POINTER", cobj)) {
+        Py_XDECREF(cobj);
+        Py_DECREF(module);
+        return NULL;
     }
     cobj =
         PyCapsule_New(&queue_music, "pygame.music_mixer._QUEUE_POINTER", NULL);
-    if (cobj == NULL) {
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+    if (PyModule_AddObject(module, "_QUEUE_POINTER", cobj)) {
+        Py_XDECREF(cobj);
+        Py_DECREF(module);
+        return NULL;
     }
-    if (PyModule_AddObject(module, "_QUEUE_POINTER", cobj) < 0) {
-        Py_DECREF(cobj);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
-    }
-    MODINIT_RETURN(module);
+    return module;
 }
