@@ -117,12 +117,6 @@ check_value(PyObject *o, const char *name)
     return 0;
 }
 
-#if PY_MAJOR_VERSION < 3
-#define INT_AS_PY_SSIZE_T(o) (PyInt_AsSsize_t(o))
-#else
-#define INT_AS_PY_SSIZE_T(o) (PyLong_AsSsize_t(o))
-#endif
-
 static int
 set_void_ptr(void **vpp, PyObject *o, const char *name)
 {
@@ -131,7 +125,7 @@ set_void_ptr(void **vpp, PyObject *o, const char *name)
     if (check_value(o, name)) {
         return -1;
     }
-    if (INT_CHECK(o)) {
+    if (PyLong_Check(o)) {
         vp = PyLong_AsVoidPtr(o);
         if (PyErr_Occurred()) {
             return -1;
@@ -158,13 +152,13 @@ set_py_ssize_t(Py_ssize_t *ip, PyObject *o, const char *name)
     if (check_value(o, name)) {
         return -1;
     }
-    if (!INT_CHECK(o)) {
+    if (!PyLong_Check(o)) {
         PyErr_Format(PyExc_TypeError,
                      "property %100s must be a Python integer, not '%400s'",
                      name, Py_TYPE(o)->tp_name);
         return -1;
     }
-    i = INT_AS_PY_SSIZE_T(o);
+    i = PyLong_AsSsize_t(o);
     if (PyErr_Occurred()) {
         return -1;
     }
@@ -230,7 +224,7 @@ buffer_init(BufferObject *self, PyObject *args, PyObject *kwds)
         py_address = 0;
     }
     if (py_address) {
-        if (INT_CHECK(py_address)) {
+        if (PyLong_Check(py_address)) {
             view_p = (Py_buffer *)PyLong_AsVoidPtr(py_address);
             if (PyErr_Occurred()) {
                 return -1;
@@ -337,7 +331,7 @@ buffer_get_buffer(BufferObject *self, PyObject *args, PyObject *kwds)
 }
 
 static PyObject *
-buffer_release_buffer(BufferObject *self, PyObject *args)
+buffer_release_buffer(BufferObject *self, PyObject *_null)
 {
     int flags = self->flags;
     Py_buffer *view_p = self->view_p;
@@ -430,7 +424,6 @@ buffer_get_buf(BufferObject *self, void *closure)
 static int
 buffer_set_buf(BufferObject *self, PyObject *value, void *closure)
 {
-
     DEL_ATTR_NOT_SUPPORTED_CHECK("buf", value);
 
     if (check_view_set(self, (const char *)closure)) {
@@ -451,7 +444,6 @@ buffer_get_len(BufferObject *self, void *closure)
 static int
 buffer_set_len(BufferObject *self, PyObject *value, void *closure)
 {
-
     DEL_ATTR_NOT_SUPPORTED_CHECK("len", value);
 
     if (check_view_set(self, (const char *)closure)) {
@@ -702,104 +694,26 @@ buffer_bool(BufferObject *self)
     return self->view_p != NULL;
 }
 
-static PyNumberMethods buffer_as_number = {
-    (binaryfunc)0, /* nb_add */
-    (binaryfunc)0, /* nb_subtract */
-    (binaryfunc)0, /* nb_multiply */
-#if PY_MAJOR_VERSION < 3
-    (binaryfunc)0, /* nb_divide */
-#endif
-    (binaryfunc)0,        /* nb_remainder */
-    (binaryfunc)0,        /* nb_divmod */
-    (ternaryfunc)0,       /* nb_power */
-    (unaryfunc)0,         /* nb_negative */
-    (unaryfunc)0,         /* nb_positive */
-    (unaryfunc)0,         /* nb_absolute */
-    (inquiry)buffer_bool, /* nb_nonzero / nb_bool */
-    (unaryfunc)0,         /* nb_invert */
-    (binaryfunc)0,        /* nb_lshift */
-    (binaryfunc)0,        /* nb_rshift */
-    (binaryfunc)0,        /* nb_and */
-    (binaryfunc)0,        /* nb_xor */
-    (binaryfunc)0,        /* nb_or */
-#if PY_MAJOR_VERSION < 3
-    (coercion)0, /* nb_coerce */
-#endif
-    (unaryfunc)0, /* nb_int */
-#if PY_MAJOR_VERSION < 3
-    (unaryfunc)0, /* nb_long */
-#else
-    0, /* nb_reserved */
-#endif
-    (unaryfunc)0, /* nb_float */
-#if PY_MAJOR_VERSION < 3
-    (unaryfunc)0, /* nb_oct */
-    (unaryfunc)0, /* nb_hex */
-#endif
-    (binaryfunc)0, /* nb_inplace_add */
-    (binaryfunc)0, /* nb_inplace_subtract */
-    (binaryfunc)0, /* nb_inplace_multiply */
-#if PY_MAJOR_VERSION < 3
-    (binaryfunc)0, /* nb_inplace_divide */
-#endif
-    (binaryfunc)0,  /* nb_inplace_remainder */
-    (ternaryfunc)0, /* nb_inplace_power */
-    (binaryfunc)0,  /* nb_inplace_lshift */
-    (binaryfunc)0,  /* nb_inplace_rshift */
-    (binaryfunc)0,  /* nb_inplace_and */
-    (binaryfunc)0,  /* nb_inplace_xor */
-    (binaryfunc)0,  /* nb_inplace_or */
-    (binaryfunc)0,  /* nb_floor_divide */
-    (binaryfunc)0,  /* nb_true_divide */
-    (binaryfunc)0,  /* nb_inplace_floor_divide */
-    (binaryfunc)0,  /* nb_inplace_true_divide */
-    (unaryfunc)0, /* nb_index */
-};
+static PyNumberMethods buffer_as_number = {.nb_bool = (inquiry)buffer_bool};
 
 #define BUFFER_TYPE_FULLNAME "newbuffer.Py_buffer"
 #define BUFFER_TPFLAGS \
     (Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC)
 
 static PyTypeObject Py_buffer_Type = {
-    PyVarObject_HEAD_INIT(NULL,0)
-    BUFFER_TYPE_FULLNAME,                    /* tp_name */
-    sizeof(BufferObject),                    /* tp_basicsize */
-    0,                                       /* tp_itemsize */
-    (destructor)buffer_dealloc,              /* tp_dealloc */
-    0,                                       /* tp_print */
-    0,                                       /* tp_getattr */
-    0,                                       /* tp_setattr */
-    0,                                       /* tp_compare */
-    0,                                       /* tp_repr */
-    &buffer_as_number,                       /* tp_as_number */
-    0,                                       /* tp_as_sequence */
-    0,                                       /* tp_as_mapping */
-    0,                                       /* tp_hash */
-    0,                                       /* tp_call */
-    0,                                       /* tp_str */
-    0,                                       /* tp_getattro */
-    0,                                       /* tp_setattro */
-    0,                                       /* tp_as_buffer */
-    BUFFER_TPFLAGS,                          /* tp_flags */
-    "Python level Py_buffer struct wrapper\n",
-    (traverseproc)buffer_traverse, /* tp_traverse */
-    0,                             /* tp_clear */
-    0,                             /* tp_richcompare */
-    0,                             /* tp_weaklistoffset */
-    0,                             /* tp_iter */
-    0,                             /* tp_iternext */
-    buffer_methods,                /* tp_methods */
-    0,                             /* tp_members */
-    buffer_getset,                 /* tp_getset */
-    0,                             /* tp_base */
-    0,                             /* tp_dict */
-    0,                             /* tp_descr_get */
-    0,                             /* tp_descr_set */
-    0,                             /* tp_dictoffset */
-    (initproc)buffer_init,         /* tp_init */
-    PyType_GenericAlloc,           /* tp_alloc */
-    buffer_new,                    /* tp_new */
-    PyObject_GC_Del,               /* tp_free */
+    PyVarObject_HEAD_INIT(NULL, 0).tp_name = BUFFER_TYPE_FULLNAME,
+    .tp_basicsize = sizeof(BufferObject),
+    .tp_dealloc = (destructor)buffer_dealloc,
+    .tp_as_number = &buffer_as_number,
+    .tp_flags = BUFFER_TPFLAGS,
+    .tp_doc = "Python level Py_buffer struct wrapper\n",
+    .tp_traverse = (traverseproc)buffer_traverse, /* tp_traverse */
+    .tp_methods = buffer_methods,
+    .tp_getset = buffer_getset,
+    .tp_init = (initproc)buffer_init,
+    .tp_alloc = PyType_GenericAlloc,
+    .tp_new = buffer_new,
+    .tp_free = PyObject_GC_Del,
 };
 
 static PyObject *
@@ -889,8 +803,8 @@ mixin_releasebuffer(PyObject *self, Py_buffer *view_p)
     PyObject *py_view = Buffer_New(view_p, 1, 1);
 
     if (py_view) {
-         PyObject *py_rval =
-             PyObject_CallMethod(self, "_release_buffer", "(O)", py_view);
+        PyObject *py_rval =
+            PyObject_CallMethod(self, "_release_buffer", "(O)", py_view);
 
         if (py_rval) {
             Py_DECREF(py_rval);
@@ -907,71 +821,21 @@ mixin_releasebuffer(PyObject *self, Py_buffer *view_p)
 }
 
 static PyBufferProcs mixin_bufferprocs = {
-#if PY_VERSION_HEX < 0x03000000
-    0,
-    0,
-    0,
-    0,
-#endif
-    (getbufferproc)mixin_getbuffer,
-    (releasebufferproc)mixin_releasebuffer};
+    (getbufferproc)mixin_getbuffer, (releasebufferproc)mixin_releasebuffer};
 
-#if PY_VERSION_HEX < 0x03000000
-#define MIXIN_TPFLAGS \
-    (Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_NEWBUFFER)
-#else
 #define MIXIN_TPFLAGS (Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE)
-#endif
-
 #define BUFFER_MIXIN_TYPE_FULLNAME "newbuffer.BufferMixin"
 
 static PyTypeObject BufferMixin_Type = {
-    PyVarObject_HEAD_INIT(NULL,0)
-    BUFFER_MIXIN_TYPE_FULLNAME,                    /* tp_name */
-    sizeof(PyObject),                              /* tp_basicsize */
-    0,                                             /* tp_itemsize */
-    0,                                             /* tp_dealloc */
-    0,                                             /* tp_print */
-    0,                                             /* tp_getattr */
-    0,                                             /* tp_setattr */
-    0,                                             /* tp_compare */
-    0,                                             /* tp_repr */
-    0,                                             /* tp_as_number */
-    0,                                             /* tp_as_sequence */
-    0,                                             /* tp_as_mapping */
-    0,                                             /* tp_hash */
-    0,                                             /* tp_call */
-    0,                                             /* tp_str */
-    0,                                             /* tp_getattro */
-    0,                                             /* tp_setattro */
-    &mixin_bufferprocs,                            /* tp_as_buffer */
-    MIXIN_TPFLAGS,                                 /* tp_flags */
-    "Python level new buffer protocol exporter\n",
-    0,                   /* tp_traverse */
-    0,                   /* tp_clear */
-    0,                   /* tp_richcompare */
-    0,                   /* tp_weaklistoffset */
-    0,                   /* tp_iter */
-    0,                   /* tp_iternext */
-    mixin_methods,       /* tp_methods */
-    0,                   /* tp_members */
-    0,                   /* tp_getset */
-    0,                   /* tp_base */
-    0,                   /* tp_dict */
-    0,                   /* tp_descr_get */
-    0,                   /* tp_descr_set */
-    0,                   /* tp_dictoffset */
-    0,                   /* tp_init */
-    PyType_GenericAlloc, /* tp_alloc */
-    PyType_GenericNew,   /* tp_new */
-    PyObject_Del,        /* tp_free */
-    0,                   /* tp_is_gc */
-    0,                   /* tp_bases */
-    0,                   /* tp_mro */
-    0,                   /* tp_cache */
-    0,                   /* tp_subclasses */
-    0,                   /* tp_weaklist */
-    0                    /* tp_del */
+    PyVarObject_HEAD_INIT(NULL, 0).tp_name = BUFFER_MIXIN_TYPE_FULLNAME,
+    .tp_basicsize = sizeof(PyObject),
+    .tp_as_buffer = &mixin_bufferprocs,
+    .tp_flags = MIXIN_TPFLAGS,
+    .tp_doc = "Python level new buffer protocol exporter\n",
+    .tp_methods = mixin_methods,
+    .tp_alloc = PyType_GenericAlloc,
+    .tp_new = PyType_GenericNew,
+    .tp_free = PyObject_Del,
 };
 
 /*DOC*/ static char newbuffer_doc[] =
@@ -981,7 +845,6 @@ MODINIT_DEFINE(newbuffer)
 {
     PyObject *module;
 
-#if PY3
     static struct PyModuleDef _module = {PyModuleDef_HEAD_INIT,
                                          "newbuffer",
                                          newbuffer_doc,
@@ -991,37 +854,35 @@ MODINIT_DEFINE(newbuffer)
                                          NULL,
                                          NULL,
                                          NULL};
-#endif
 
     /* prepare exported types */
     if (PyType_Ready(&Py_buffer_Type) < 0) {
-        MODINIT_ERROR;
+        return NULL;
     }
     if (PyType_Ready(&BufferMixin_Type) < 0) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
 #define bufferproxy_docs ""
 
     /* create the module */
-#if PY3
     module = PyModule_Create(&_module);
-#else
-    module = Py_InitModule3("newbuffer", 0, newbuffer_doc);
-#endif
+    if (!module) {
+        return NULL;
+    }
 
     Py_INCREF(&BufferMixin_Type);
     if (PyModule_AddObject(module, "BufferMixin",
                            (PyObject *)&BufferMixin_Type)) {
         Py_DECREF(&BufferMixin_Type);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
     Py_INCREF(&Py_buffer_Type);
     if (PyModule_AddObject(module, "Py_buffer", (PyObject *)&Py_buffer_Type)) {
         Py_DECREF(&Py_buffer_Type);
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
     if (Module_AddSsize_tConstant(module, "PyBUFFER_SIZEOF",
                                   sizeof(Py_buffer)) ||
@@ -1042,8 +903,8 @@ MODINIT_DEFINE(newbuffer)
         PyModule_AddIntMacro(module, PyBUF_FULL_RO) ||
         PyModule_AddIntMacro(module, PyBUF_CONTIG) ||
         PyModule_AddIntMacro(module, PyBUF_CONTIG_RO)) {
-        DECREF_MOD(module);
-        MODINIT_ERROR;
+        Py_DECREF(module);
+        return NULL;
     }
-    MODINIT_RETURN(module);
+    return module;
 }
