@@ -21,35 +21,27 @@
 */
 
 #include <stddef.h>
-#include "pygame.h"
 
-#if IS_SDLv2
 #include "palette.h"
-#endif /* IS_SDLv2 */
 
 #include "pgcompat.h"
 
 #include "doc/pixelcopy_doc.h"
 
-#if IS_SDLv1
-#include <SDL_byteorder.h>
-#else /* IS_SDLv2 */
 #include <SDL_endian.h>
-#endif /* IS_SDLv2 */
 
 typedef enum {
-    VIEWKIND_RED,
-    VIEWKIND_GREEN,
-    VIEWKIND_BLUE,
-    VIEWKIND_ALPHA,
+    PXC_VIEWKIND_RED,
+    PXC_VIEWKIND_GREEN,
+    PXC_VIEWKIND_BLUE,
+    PXC_VIEWKIND_ALPHA,
     VIEWKIND_COLORKEY,
     VIEWKIND_RGB
 } _pc_view_kind_t;
 
-typedef union {
-    Uint32 value;
-    Uint8 bytes[sizeof(Uint32)];
-} _pc_pixel_t;
+#if !defined(BUILD_STATIC)
+
+#include "pygame.h"
 
 static int
 _validate_view_format(const char *format)
@@ -103,7 +95,7 @@ _validate_view_format(const char *format)
             /* default: unrecognized character; raise error later */
     }
     if (format[i] != '\0') {
-        PyErr_SetString(PyExc_ValueError, "Unsupport array item type");
+        PyErr_SetString(PyExc_ValueError, "Unsupported array item type");
         return -1;
     }
 
@@ -134,29 +126,20 @@ _view_kind(PyObject *obj, void *view_kind_vptr)
     _pc_view_kind_t *view_kind_ptr = (_pc_view_kind_t *)view_kind_vptr;
 
     if (PyUnicode_Check(obj)) {
-#if PY2
-        if (PyUnicode_GET_SIZE(obj) != 1) {
-            PyErr_SetString(PyExc_TypeError,
-                            "expected a length 1 string for argument 3");
-            return 0;
-        }
-        ch = *PyUnicode_AS_UNICODE(obj);
-#else
         if (PyUnicode_GET_LENGTH(obj) != 1) {
             PyErr_SetString(PyExc_TypeError,
                             "expected a length 1 string for argument 3");
             return 0;
         }
         ch = PyUnicode_READ_CHAR(obj, 0);
-#endif
     }
-    else if (Bytes_Check(obj)) {
-        if (Bytes_GET_SIZE(obj) != 1) {
+    else if (PyBytes_Check(obj)) {
+        if (PyBytes_GET_SIZE(obj) != 1) {
             PyErr_SetString(PyExc_TypeError,
                             "expected a length 1 string for argument 3");
             return 0;
         }
-        ch = *Bytes_AS_STRING(obj);
+        ch = *PyBytes_AS_STRING(obj);
     }
     else {
         PyErr_Format(PyExc_TypeError,
@@ -167,19 +150,19 @@ _view_kind(PyObject *obj, void *view_kind_vptr)
     switch (ch) {
         case 'R':
         case 'r':
-            *view_kind_ptr = VIEWKIND_RED;
+            *view_kind_ptr = PXC_VIEWKIND_RED;
             break;
         case 'G':
         case 'g':
-            *view_kind_ptr = VIEWKIND_GREEN;
+            *view_kind_ptr = PXC_VIEWKIND_GREEN;
             break;
         case 'B':
         case 'b':
-            *view_kind_ptr = VIEWKIND_BLUE;
+            *view_kind_ptr = PXC_VIEWKIND_BLUE;
             break;
         case 'A':
         case 'a':
-            *view_kind_ptr = VIEWKIND_ALPHA;
+            *view_kind_ptr = PXC_VIEWKIND_ALPHA;
             break;
         case 'C':
         case 'c':
@@ -198,11 +181,18 @@ _view_kind(PyObject *obj, void *view_kind_vptr)
     return 1;
 }
 
+#endif  // BUILD_STATIC
+
+typedef union {
+    Uint32 value;
+    Uint8 bytes[sizeof(Uint32)];
+} _pc_pixel_t;
+
 static int
 _copy_mapped(Py_buffer *view_p, SDL_Surface *surf)
 {
-    int pixelsize = surf->format->BytesPerPixel;
-    int intsize = view_p->itemsize;
+    Uint8 pixelsize = surf->format->BytesPerPixel;
+    Py_ssize_t intsize = view_p->itemsize;
 #if SDL_BYTEORDER == SDL_LIL_ENDIAN
     char *src = (char *)surf->pixels;
 #else
@@ -268,11 +258,7 @@ _copy_colorplane(Py_buffer *view_p, SDL_Surface *surf,
 {
     SDL_PixelFormat *format = surf->format;
     int pixelsize = surf->format->BytesPerPixel;
-#if IS_SDLv1
-    Uint32 flags = surf->flags;
-#else /* IS_SDLv2 */
     SDL_BlendMode mode;
-#endif /* IS_SDLv2 */
     int intsize = (int)view_p->itemsize;
     char *src = (char *)surf->pixels;
     char *dst = (char *)view_p->buf;
@@ -302,26 +288,24 @@ _copy_colorplane(Py_buffer *view_p, SDL_Surface *surf,
                      intsize);
         return -1;
     }
-#if IS_SDLv2
     if (SDL_GetSurfaceBlendMode(surf, &mode) < 0) {
         PyErr_SetString(pgExc_SDLError, SDL_GetError());
         return -1;
     }
-#endif
     /* Select appropriate color plane element within the pixel */
     switch (view_kind) {
-        case VIEWKIND_RED:
+        case PXC_VIEWKIND_RED:
             element = &r;
             break;
-        case VIEWKIND_GREEN:
+        case PXC_VIEWKIND_GREEN:
             element = &g;
             break;
-        case VIEWKIND_BLUE:
+        case PXC_VIEWKIND_BLUE:
             element = &b;
             break;
-        default: /* VIEWKIND_ALPHA or VIEWKIND_COLORKEY */
+        default: /* PXC_VIEWKIND_ALPHA or VIEWKIND_COLORKEY */
             /* element is unused for VIEWKIND_COLORKEY */
-            assert(view_kind == VIEWKIND_ALPHA ||
+            assert(view_kind == PXC_VIEWKIND_ALPHA ||
                    view_kind == VIEWKIND_COLORKEY);
             element = &a;
     }
@@ -338,13 +322,8 @@ _copy_colorplane(Py_buffer *view_p, SDL_Surface *surf,
         dz_dst = -1;
     }
 #endif
-#if IS_SDLv1
-    if (view_kind == VIEWKIND_COLORKEY && flags & SDL_SRCCOLORKEY) {
-        colorkey = format->colorkey;
-#else  /* IS_SDLv2 */
     if (view_kind == VIEWKIND_COLORKEY &&
         SDL_GetColorKey(surf, &colorkey) == 0) {
-#endif /* IS_SDLv2 */
         for (x = 0; x < w; ++x) {
             for (y = 0; y < h; ++y) {
                 for (z = 0; z < pixelsize; ++z) {
@@ -358,13 +337,8 @@ _copy_colorplane(Py_buffer *view_p, SDL_Surface *surf,
             }
         }
     }
-#if IS_SDLv1
     else if ((view_kind != VIEWKIND_COLORKEY) &&
-             (view_kind != VIEWKIND_ALPHA || flags & SDL_SRCALPHA)) {
-#else  /* IS_SDLv2 */
-    else if ((view_kind != VIEWKIND_COLORKEY) &&
-             (view_kind != VIEWKIND_ALPHA || mode != SDL_BLENDMODE_NONE)) {
-#endif /* IS_SDLv2 */
+             (view_kind != PXC_VIEWKIND_ALPHA || mode != SDL_BLENDMODE_NONE)) {
         for (x = 0; x < w; ++x) {
             for (y = 0; y < h; ++y) {
                 for (z = 0; z < pixelsize; ++z) {
@@ -497,7 +471,7 @@ array_to_surface(PyObject *self, PyObject *arg)
     SDL_Surface *surf;
     SDL_PixelFormat *format;
     int loopx, loopy;
-    int stridex, stridey, stridez = 0, stridez2 = 0, sizex, sizey;
+    Py_ssize_t stridex, stridey, stridez = 0, stridez2 = 0, sizex, sizey;
     int Rloss, Gloss, Bloss, Rshift, Gshift, Bshift;
 
     if (!PyArg_ParseTuple(arg, "O!O", &pgSurface_Type, &surfobj, &arrayobj)) {
@@ -519,7 +493,7 @@ array_to_surface(PyObject *self, PyObject *arg)
     }
 
     if (surf->format->BytesPerPixel == 0 || surf->format->BytesPerPixel > 4)
-        return RAISE(PyExc_ValueError, "unsupport bit depth for surface");
+        return RAISE(PyExc_ValueError, "unsupported bit depth for surface");
 
     stridex = view_p->strides[0];
     stridey = view_p->strides[1];
@@ -846,7 +820,7 @@ surface_to_array(PyObject *self, PyObject *args, PyObject *kwds)
     else {
         pgBuffer_Release(&pg_view);
         pgSurface_Unlock(surfobj);
-        PyErr_Format(PyExc_ValueError, "Unsupported array depth %d",
+        PyErr_Format(PyExc_ValueError, "unsupported array depth %d",
                      (int)view_p->ndim);
         return 0;
     }
@@ -867,7 +841,8 @@ map_array(PyObject *self, PyObject *args)
     pgSurfaceObject *format_surf;
     SDL_PixelFormat *format;
     pg_buffer src_pg_view;
-    Py_buffer *src_view_p = 0;
+    Py_buffer *src_view_p;
+    Uint8 is_src_alloc = 0;
     Uint8 *src;
     int src_ndim;
     Py_intptr_t src_strides[PIXELCOPY_MAX_DIM];
@@ -875,27 +850,28 @@ map_array(PyObject *self, PyObject *args)
     int src_green;
     int src_blue;
     pg_buffer tar_pg_view;
-    Py_buffer *tar_view_p = 0;
+    Py_buffer *tar_view_p;
+    Uint8 is_tar_alloc = 0;
     Uint8 *tar;
     int ndim;
     Py_intptr_t *shape;
     Py_intptr_t *tar_strides;
-    int tar_itemsize;
+    Py_ssize_t tar_itemsize;
     int tar_byte0 = 0;
     int tar_byte1 = 0;
     int tar_byte2 = 0;
     int tar_byte3 = 0;
-    int tar_padding_start;
-    int tar_padding_end;
+    Py_ssize_t tar_padding_start;
+    Py_ssize_t tar_padding_end;
     Py_intptr_t counters[PIXELCOPY_MAX_DIM];
-    int src_advances[PIXELCOPY_MAX_DIM];
-    int tar_advances[PIXELCOPY_MAX_DIM];
+    Py_ssize_t src_advances[PIXELCOPY_MAX_DIM] = {0};
+    Py_ssize_t tar_advances[PIXELCOPY_MAX_DIM] = {0};
     int dim_diff;
     int dim;
     int topdim;
     _pc_pixel_t pixel = {0};
     int pix_bytesize;
-    int i;
+    Py_ssize_t i;
 
     if (!PyArg_ParseTuple(args, "OOO!", &tar_array, &src_array,
                           &pgSurface_Type, &format_surf)) {
@@ -911,6 +887,7 @@ map_array(PyObject *self, PyObject *args)
     if (pgObject_GetBuffer(tar_array, &tar_pg_view, PyBUF_RECORDS)) {
         goto fail;
     }
+    is_tar_alloc = 1;
     tar_view_p = (Py_buffer *)&tar_pg_view;
     tar = (Uint8 *)tar_view_p->buf;
     if (_validate_view_format(tar_view_p->format)) {
@@ -933,6 +910,7 @@ map_array(PyObject *self, PyObject *args)
     if (pgObject_GetBuffer(src_array, &src_pg_view, PyBUF_RECORDS_RO)) {
         goto fail;
     }
+    is_src_alloc = 1;
     src_view_p = (Py_buffer *)&src_pg_view;
     if (_validate_view_format(src_view_p->format)) {
         goto fail;
@@ -991,7 +969,7 @@ map_array(PyObject *self, PyObject *args)
                         "target array itemsize is too small for pixel format");
         goto fail;
     }
-    src_green = src_view_p->strides[src_ndim - 1];
+    src_green = (int)src_view_p->strides[src_ndim - 1];
     src_blue = 2 * src_green;
     switch (pix_bytesize) {
         case 1:
@@ -1086,6 +1064,13 @@ map_array(PyObject *self, PyObject *args)
             /* Leave loop, moving left one index
              */
             --dim;
+            if (dim < 0) {
+                /* Should not happen, but handle case for extra safety */
+                PyErr_SetString(
+                    PyExc_RuntimeError,
+                    "internal pygame error in pixelcopy map_array");
+                goto fail;
+            }
             tar += tar_advances[dim];
             src += src_advances[dim];
             --counters[dim];
@@ -1136,10 +1121,10 @@ map_array(PyObject *self, PyObject *args)
     Py_RETURN_NONE;
 
 fail:
-    if (src_view_p) {
+    if (is_src_alloc) {
         pgBuffer_Release(&src_pg_view);
     }
-    if (tar_view_p) {
+    if (is_tar_alloc) {
         pgBuffer_Release(&tar_pg_view);
     }
     pgSurface_Unlock(format_surf);
@@ -1173,15 +1158,9 @@ make_surface(PyObject *self, PyObject *arg)
 
     if (view_p->ndim == 2) {
         bitsperpixel = 8;
-#if IS_SDLv1
-        rmask = 0xFF >> 6 << 5;
-        gmask = 0xFF >> 5 << 2;
-        bmask = 0xFF >> 6;
-#else  /* IS_SDLv2 */
         rmask = 0;
         gmask = 0;
         bmask = 0;
-#endif /* IS_SDLv2 */
     }
     else {
         bitsperpixel = 32;
@@ -1189,8 +1168,8 @@ make_surface(PyObject *self, PyObject *arg)
         gmask = 0xFF << 8;
         bmask = 0xFF;
     }
-    sizex = view_p->shape[0];
-    sizey = view_p->shape[1];
+    sizex = (int)view_p->shape[0];
+    sizey = (int)view_p->shape[1];
 
     surf = SDL_CreateRGBSurface(0, sizex, sizey, bitsperpixel, rmask, gmask,
                                 bmask, 0);
@@ -1198,7 +1177,6 @@ make_surface(PyObject *self, PyObject *arg)
         pgBuffer_Release(&pg_view);
         return RAISE(pgExc_SDLError, SDL_GetError());
     }
-#if IS_SDLv2
     if (SDL_ISPIXELFORMAT_INDEXED(surf->format->format)) {
         /* Give the surface something other than an all white palette.
          *          */
@@ -1209,7 +1187,6 @@ make_surface(PyObject *self, PyObject *arg)
             return 0;
         }
     }
-#endif /* IS_SDLv2 */
     surfobj = pgSurface_New(surf);
     if (!surfobj) {
         pgBuffer_Release(&pg_view);
@@ -1247,7 +1224,6 @@ static PyMethodDef _pixelcopy_methods[] = {
 
 MODINIT_DEFINE(pixelcopy)
 {
-#if PY3
     static struct PyModuleDef _module = {PyModuleDef_HEAD_INIT,
                                          "pixelcopy",
                                          DOC_PYGAMEPIXELCOPY,
@@ -1257,23 +1233,18 @@ MODINIT_DEFINE(pixelcopy)
                                          NULL,
                                          NULL,
                                          NULL};
-#endif
 
     /* imported needed apis; Do this first so if there is an error
        the module is not loaded.
     */
     import_pygame_base();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
     import_pygame_surface();
     if (PyErr_Occurred()) {
-        MODINIT_ERROR;
+        return NULL;
     }
 
-#if PY3
     return PyModule_Create(&_module);
-#else
-    Py_InitModule3("pixelcopy", _pixelcopy_methods, DOC_PYGAMEPIXELCOPY);
-#endif
 }
